==> haskell-base64-bytestring-1.2.1.0-268-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-base64-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64-bytestring
version:              1.2.1.0
visibility:           public
id:                   base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
key:                  base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
license:              BSD-3-Clause
copyright:            2010-2020 Bryan O'\''Sullivan et al.
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Mikhail Glushenkov <mikhail.glushenkov@gmail.com>,
    Emily Pillmore <emilypi@cohomolo.gy>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/base64-bytestring
synopsis:             Fast base64 encoding and decoding for ByteStrings
description:
    This package provides support for encoding and decoding binary data according to @base64@ (see also <https://tools.ietf.org/html/rfc4648 RFC 4648>) for strict and lazy ByteStrings

    For a fuller-featured and better-performing Base64 library, see the <https://hackage.haskell.org/package/base64 base64> package.

category:             Data
abi:                  9e19365910bd5371d4997108aadfe553
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.Lazy
    Data.ByteString.Base64.URL Data.ByteString.Base64.URL.Lazy

hidden-modules:       Data.ByteString.Base64.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64-bytestring
hs-libraries:         HSbase64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-base64-bytestring/html/base64-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-base64-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base64-bytestring-1.2.1.0-270-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-base64-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64-bytestring
version:              1.2.1.0
visibility:           public
id:                   base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
key:                  base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
license:              BSD-3-Clause
copyright:            2010-2020 Bryan O'\''Sullivan et al.
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Mikhail Glushenkov <mikhail.glushenkov@gmail.com>,
    Emily Pillmore <emilypi@cohomolo.gy>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/base64-bytestring
synopsis:             Fast base64 encoding and decoding for ByteStrings
description:
    This package provides support for encoding and decoding binary data according to @base64@ (see also <https://tools.ietf.org/html/rfc4648 RFC 4648>) for strict and lazy ByteStrings

    For a fuller-featured and better-performing Base64 library, see the <https://hackage.haskell.org/package/base64 base64> package.

category:             Data
abi:                  f21318073ebbe3429192fbdad3f5b64b
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.Lazy
    Data.ByteString.Base64.URL Data.ByteString.Base64.URL.Lazy

hidden-modules:       Data.ByteString.Base64.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/base64-bytestring-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64-bytestring
hs-libraries:         HSbase64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-base64-bytestring/html/base64-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-base64-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
